                                  SCRIBE
                                  ======

A versatile text editor for the Atari ST/TT series of computers.

INTRODUCTION
------------

SCRIBE is a fast and easy-to-use text editor. It can be used for any text 
editing purpose, such as preparing text for use in a word processor or 
desktop publishing program, creating program source code, or modifying 
auxiliary files such as DESKTOP.INF (or high score tables for games!).

Although designed to be very easy to learn, it also provides a 
comprehensive set of facilities:-

* Friendly GEM window environment
* Works in any screen resolution, including Overscan modes
* Up to ten documents in memory at one time
* Single key switching between documents
* Ten separate clipboards, with editable descriptions
* Extended set of block functions
* Copy and move blocks between documents
* Word wrapping with continuous text reflow during editing
* Search and replace
* 'Undo' facility
* Keyboard alternatives for all menu commands
* Auto recognition of documents having line-feed-only paragraph endings
* Resetting of paragraphs in documents having CR/LF after every line
* Document printing with headers and footers
* On-line help
* Optional expert mode
* User defined defaults
* Memory management facility for multi-tasking environment
* Floppy disk formatting

** Note: Although SCRIBE should work in any screen mode, there are 
functional limitations in low resolution modes. See 'TECHNICAL NOTES' at 
the end of this manual for more information.

CONVENTIONS
-----------

In this manual the following conventions are used:-

Keyboard keys are described in the same way as they are labelled on the 
keyboard, e.g. Return, Undo, etc.

When a key combination is required, it is given in the following form:
'<Control> left-arrow' (means hold down the Control key while pressing the 
left arrow key).

When a particular command can be issued by different means, such as a key 
press or a drop-down menu selection, the keyboard version is given in the 
main description and any alternatives are given at the end of the 
description.

In the drop-down menus, the keyboard alternatives are displayed after the 
command; most of these are <Control> or <Alternate> key combinations, and 
these are indicated by the symbol '^' (for <Control>) or '@' (for 
<Alternate>) followed by a letter or name of a key. For example, '^K' means 
<Control> K.

To help you remember when to use <Control> and when to use <Alternate>, the 
'Edit', 'Block' and 'Search' drop-down menus are duplicated by <Control> 
combinations, and the 'Desk', 'File', 'Print' and 'Utilities' menus by 
<Alternate> combinations.

GETTING STARTED
---------------

SCRIBE can be run from any disk drive, and within any folder. The following 
files should all be together, either in the same folder, or in the root 
directory of the disk (i.e. not in any folder):-

SCRIBE.PRG - The SCRIBE program
SCRIBE.RSC - The resource file
SCRIBE.HLP - The on-line help file
SCRIBE.DEF - The file of default settings for SCRIBE

The last two files are not essential; if they are absent, SCRIBE will use 
its own programmed default settings, and on-line help will not be 
available. There may be other files on the distribution disk, but these are 
not part of SCRIBE. In particular, there is a file named README.1ST; you 
should read or print this file before running SCRIBE, because it may 
contain some late amendments to this instruction manual. It will also 
contain details of any supplementary files which are supplied with the 
program.

To run SCRIBE, double-click on the SCRIBE.PRG icon. The program will load, 
and after a short time the text entry screen will be displayed. This screen 
consists of a conventional GEM window, with a drop-down menu line at the 
top. If you are not familiar with these features, they are explained in 
your computer's instruction manual.

If you move the mouse pointer up to the menu line, you will see that 
several of the menu items are displayed in a faint grey colour. This is 
because the functions which they represent are not available at present, 
and these items cannot be selected. For example, you cannot use any of the 
block functions until a block has first been defined. As you work with 
SCRIBE these functions will automatically become available as appropriate.

Under the drop-down menu is the title line of the window. At first this 
contains only the name of the program, but when you save or load a 
document, its name will appear in the title line.

Under the title line is the information line; this contains information on 
the current state of several of the user adjustable settings of the 
program, and when you change these settings the new situation will be shown 
in the information line. During certain operations, other details will be 
displayed in the information line, to let you know what is happening or to 
tell you what to do next.

At the right hand side of the window is a scroll bar; if your text occupies 
more than a full screen, the scroll bar can be used to move to a different 
part of the text. You can click on the grey parts to move up or down one 
screen at a time, or drag the white slider to move a greater distance. Use 
of the scroll bar is described more fully later in this manual.

At the top left hand corner of the window is the 'close box'. Clicking on 
this will erase the current document from memory. If there is no text in 
memory, clicking on the close box will exit from SCRIBE.

There is no horizontal scroll bar on the window because SCRIBE uses 
word-wrap instead.

USING SCRIBE
------------

SCRIBE is used in much the same way as a word processor - you type on the 
keyboard, and the text which you type is displayed on the screen, and 
simultaneously stored in the computer's memory. When you reach the end of a 
screen line, any uncompleted word is automatically transferred to the start 
of the next line, so ensuring that no words are split between lines. This 
'word wrapping' is automatically maintained during all editing operations.

In the following description, it is assumed that the text cursor is in its 
default state, i.e. a solid block. However, as we will see later, it is 
possible to change it to a vertical line; if you choose to do this, then 
where the manual refers to 'under the cursor' you should take this to mean 
'to the right of the cursor'.

The editing commands of SCRIBE are as follows:-

Typing and erasing text
-----------------------

Insert - pressing this key toggles the typing mode between 'Insert' and 
'Overstrike'. In 'Insert' mode, anything which you type is inserted into 
the text at the cursor position, and all succeeding text moves to the right 
to make room. In 'Overstrike' mode, a typed character normally just 
replaces the character under the cursor; however, if the cursor is on a 
paragraph end marker, the typed character will be inserted in front of the 
marker. In both cases the cursor moves one place to the right after typing 
the character.
The current mode is displayed in the information line at the top of the 
window.

Caps Lock - pressing this key toggles between 'Caps Lock on' and 'Caps Lock 
off'. When Caps Lock is on, all alphabetic characters which you type are 
output as capitals. Non-alphabetic characters are not affected.

Alternate - if you hold down this key while typing ON THE NUMERIC KEYPAD a 
number between 1 and 255, the character whose ASCII value you typed will be 
added to the text as if you typed it directly. This feature enables you to 
enter characters which are not available directly from the keyboard, such 
as various foreign language characters.
(Note) Because the Line Feed, Form Feed and Carriage Return characters 
(ASCII 10, 12 and 13) are used for special purposes in SCRIBE, you cannot 
insert them using the above method. All other values can be entered and 
edited.

Delete - deletes the character under the cursor; succeeding characters move 
left one space. If the cursor is on a paragraph end marker, the marker is 
deleted and the following paragraph is joined on the end of the current 
one; however, you cannot delete the final paragraph end marker at the end 
of the document. If the cursor is on a tab marker, the marker is deleted 
and the text is redisplayed.

Backspace - deletes the character to the left of the cursor; succeeding 
characters move left one space. If the cursor is at the start of a 
paragraph, it moves back to the marker at the end of the previous 
paragraph, and joins the two paragraphs together as described for 'Delete', 
above.

Undo - if the 'Undo' facility is enabled, pressing the Undo key will 
restore the current paragraph to the state it was in before you started to 
edit it. The cursor is placed on the first character of the paragraph.
This feature applies only so long as the cursor remains within the same 
paragraph; each time the cursor moves to a new paragraph, any changes made 
to the previous paragraph are 'fixed', and the contents of the new 
paragraph are transferred to the special 'Undo' memory buffer.
(Use of the Block functions 'Paste', 'Duplicate' and 'Move', and the file 
'Merge' function, will also reset the Undo buffer.)
Alternative: select 'Restore paragraph' from the 'Edit' drop-down menu.

<Control> W - this deletes the current word, including any following spaces 
or punctuation marks. If the cursor is on a paragraph end marker, there is 
no action.
Alternative: select 'Delete word' from the 'Edit' drop-down menu.

<Control> S - this deletes the current word and up to the end of the 
sentence. If the cursor is on a paragraph end marker, there is no action.
Alternative: select 'Delete end of sentence' from the 'Edit' drop-down 
menu.

<Control> Delete - this deletes the entire screen line on which the cursor 
is placed.
Alternative: type <Control> Y, or select 'Delete line' from the 'Edit' 
drop-down menu.

<Control> Undo - this restores a line deleted as above. If the cursor has 
been moved in the meantime, the line will be restored in front of the line 
on which the cursor is placed. This can be carried out repeatedly, to 
duplicate a line many times.
Alternative: select 'Restore line' from the 'Edit' drop-down menu.

<Control> K - this erases the current document completely from memory. If 
you have not disabled warnings, a warning message is displayed before the 
command is implemented.
Alternative: select 'Clear current document' from the 'Edit' drop-down 
menu, or click in the 'Close' box in the top left hand corner of the 
window.

<Control> Q - this erases ALL documents from memory. If you have not 
disabled warnings, a warning message is displayed before the command is 
implemented.
Alternative: select 'Clear all documents' from the 'Edit' drop-down menu.

Cursor movements
----------------

(Note concerning tabs) - Where a document includes the tab character (ASCII 
value 9), SCRIBE displays this on screen as a number of spaces.  Although 
these appear as ordinary spaces, you will not be able to place the cursor 
on them, apart from the first one (corresponding with the position of the 
tab character).

F1 to F10 - these function keys are used to jump between documents (e.g. F3 
takes you directly to document number 3). Your current position in the 
previous document is stored, and when you return to that document you will 
be at the same position.
The information line at the top of the window displays the number of the 
current document.
Alternative: Select 'Change document' from the 'Search' drop-down menu.

Left-arrow - moves the cursor one space left. If it is at the start of a 
line, it moves to the end of the previous line.

Right-arrow - moves the cursor one place right. If it is at the end of a 
line, it moves to the start of the next line.

Up-arrow - moves the cursor up one line; if it is on the top line, the text 
scrolls down. If the movement would leave the cursor placed beyond the end 
of the new line, it is moved back to the end of the line.

Down-arrow - moves the cursor down one line; if it is on the bottom line, 
the text scrolls up. If the movement would leave the cursor placed beyond 
the end of the new line, it is moved back to the end of the line.

Tab - in 'Insert' mode, a tab character (ASCII value 9) is inserted in the 
text, and the text is redisplayed. Where the tab character occurs, a number 
of spaces are displayed, so that the following character is on the next tab 
position.
In 'Overstrike' mode, the cursor moves to the next tab position, but no 
characters are inserted.
Tab positions are at 8-character intervals, starting with positions 1,9,17, 
etc. These are the same as the tab positions used by the Desktop (and also 
Neodesk) when viewing text files.

<Control> left-arrow - moves the cursor to the start of the current line.

<Control> right-arrow - moves the cursor to the end of the current line.

<Control> up-arrow - the window moves up one screen in the text (i.e. the 
text scrolls down one screen), and the cursor moves to the top of the 
screen.
Alternative: Click on the upper grey part of the scroll bar.

<Control> down-arrow - the window moves down one screen in the text (i.e. 
the text scrolls up one screen), and the cursor moves to the top of the 
screen.
Alternative: Click on the lower grey part of the scroll bar.

Clr/Home - the cursor moves to the top of the current screen.

<Control> Clr/Home - the cursor moves to the top of the text (i.e. the 
start of the current document).
Alternative: Select 'Top of text' under the 'Search' drop-down menu.

<Control> O - the cursor moves to the bottom of the current screen.

<Control> Z - the cursor moves to the bottom of the text (i.e. the end of 
the current document).
Alternative: Select 'Bottom of text' under the 'Search' drop-down menu.

Return - the action of this key varies according to the mode of operation:
- If you are in 'Insert' mode, the action of the Return key is to split the 
paragraph at the cursor position; the character under the cursor will be 
the first character of a new paragraph.
- In overstrike mode, the Return key merely moves the cursor to the start 
of the next line. If the cursor is on the last line of the document, a new 
blank paragraph is added at the end.

Click mouse in the text area - this moves the cursor directly to the 
character nearest to the mouse pointer position.

In addition to the above, the other normal functions of the scroll bar are 
available, as follows:

Click on the upwards-pointing arrow - the window moves up one line (i.e. 
the text scrolls down one line in the window). The cursor remains in the 
same position in the text, unless it was on the bottom line.

Click on the downwards-pointing arrow - the window moves down one line 
(i.e. the text scrolls up one line in the window). The cursor remains in 
the same position in the text, unless it was on the top line.

Drag the white bar up or down - the position of the white bar relative to 
the total scroll bar indicates the position of the window within the 
document (e.g. the white bar is at the top when you are at the start of the 
document). Dragging the white bar to a different position moves the window 
to that relative position within the document.

If you hold the left mouse button down while the pointer is on one of the 
grey parts of the scroll bar, the text will repeatedly scroll in the 
appropriate direction until the button is released.


DOCUMENT PRINTING
-----------------

SCRIBE is NOT a word processor, but it does provide some facilities for 
printing your document. No special printer control codes are used, so it 
should work with any conventional printer. Printing is fast, so this 
facility could be useful for producing quick draft documents.
The printing functions are found under the 'Print' drop-down menu.

Printed page layout
-------------------

This procedure will probably need to be carried out only once, unless you 
change the size of your printing paper or install a new printer. It should 
be done first, before any other printing functions. Type <Alternate> T, or 
select 'Printed page layout'.

After selecting this item a dialog box is displayed, in which you can set 
the page size, margins, etc. for hardcopy printing. The values can be 
changed by clicking on the up or down arrow symbols, or by typing numbers 
directly into the boxes. The meanings of the items are:-

Paper length - the total length of the sheet in lines. Most printers print 
6 lines per inch, so this figure is normally the length of the sheet in 
inches, multiplied by 6. Note however that some single sheet printers 
cannot print right to the top or bottom of the sheet, so this figure should 
represent the actual number of lines which the printer is capable of 
printing. For example, the Hewlett-Packard Deskjet series of printers 
normally omit the top and bottom half-inch of the sheet, so 1 inch should 
be deducted from the sheet length to calculate the total number of lines.

Top margin - the number of blank lines at the top of the sheet, not 
including any area which the printer cannot print on (see above). Must be 
at least 3 if you want to have a header.

Bottom margin - the number of blank lines at the bottom of the sheet, not 
including any area which the printer cannot print on (see above). Must be 
at least 3 if you want to have a footer.

Lines per page - the number of actual lines of text per page (automatically 
calculated from the above 3 values).

Left margin - the number of character spaces from the left of the sheet to 
the left edge of the text.

Right margin - the number of character spaces from the left of the sheet to 
the right edge of the text

Pause after page - Click on 'Yes' if your printer requires single sheets of 
paper to be fed in one at a time, otherwise click on 'No'.

Make your choices as above, then click on one of the last three buttons:-

'Save & Use' implements your choices, and also saves them to the SCRIBE.DEF 
file, so that they become the defaults when you next run SCRIBE. This also 
saves the items in the 'User preferences' dialog (described under 
'MISCELLANEOUS FUNCTIONS').

'Use' implements your choices for the current session only.

'Cancel' restores the previous settings.

Headers and footers
-------------------
Select this item if you want each printed page to carry a header and/or a 
footer. Type <Alternate> H, or select 'Headers and footers'. A dialog box 
is displayed; fill it in as follows:

Header - type a line of text of up to 40 characters, which you want to be 
printed at the top of each page.

Footer - type a line of text of up to 40 characters, which you want to be 
printed at the bottom of each page.

Header/Footer on first page - click on 'Yes' if you want the header and 
footer to be printed on the first page, or 'No' if not.

Finally click on 'OK' to accept your choices, or 'Cancel' to restore the 
previous contents of the dialog box. The information is saved with the 
document when you save it in SCRIBE format.

If you type a '#' character in either the header or the footer line, this 
will be interpreted at printing time as the current page number. Thus,  
'Page #' will be successively printed as 'Page 1', Page 2', etc.

Headers and footers are centred on the line, and are separated from the top 
and bottom of the main text by two blank lines. Therefore the top and 
bottom margins must have values of at least 3, otherwise the headers and 
footers will not be printed.

Insert page breaks
------------------

This function enables you to select the points in the text at which page 
breaks will occur. It is not essential to do this; if you do not do so, 
SCRIBE will print the maximum number of lines on each page, so that page 
breaks may occur at inconvenient points in the text. Type <Alternate> I, or 
select 'Insert page breaks'.

After selecting this item, you are first presented with an alert box which 
asks if you want already installed page breaks to be deleted first. If you 
click on 'Yes' all page breaks will be removed. If you click on 'No', the 
procedure will take account of any page breaks which it finds, and only add 
such others as are required for correct pagination.

The procedure now scans the text, counting the lines according to the 
values set in the 'Printed page layout' dialog. It stops at each point 
where a page break is required, and displays a screen of text with one line 
inverted (i.e. white characters on a black background). The inverted line 
is the last position at which a new page must start.

You can now use the up and down cursor keys to select an earlier line for 
the page break to be set at. You will not be able to move below the line 
which was originally inverted, because this would result in a page which is 
too long. When you have chosen the line at which you want the page break, 
press Return to set it, and the procedure moves on to the next break 
position. The information line at the top of the window gives a brief 
reminder of what you have to do.

Page breaks can be set on any line during this procedure. If your chosen 
line is not the first line of a paragraph, SCRIBE will break the paragraph 
at the start of the line before setting the page break. When all the 
required page breaks have been set, the start of the document is 
redisplayed. You can abort the process before it is completed by pressing 
Esc.

Page breaks are displayed in the text as a row of '=' signs. A page break 
can be manually deleted by placing the cursor on it and pressing Delete. 
The cursor can only be placed on the first character of a page break line.

When the document is saved in SCRIBE format, the page break positions are 
also saved.

(Note) If the page layout settings are such that the printed lines would be 
longer than the lines on screen, the displayed lines will be cropped to fit 
within the window during the above procedure. The beginnings of lines will 
be correctly displayed as they would be printed, but the ends of long lines 
will be hidden.

Single page break
-----------------

In addition to the automated procedure described above, individual page 
breaks can be set manually. You may want to do this first of all, to define 
points at which you particularly want page breaks to occur, such as main 
headings.

Type <Alternate> G, or select 'Single page break'. A page break will be set 
at the start of the current paragraph. If for some reason you particularly 
want a page break in the middle of a paragraph (?) you must break the 
paragraph at this point first: place the cursor where you want the page 
break to occur, then press Return (make sure that you are in 'Insert' mode 
first). Then type <Alternate> G to set the page break.

Printing a document
-------------------

Type <Alternate> P, or select 'Print document'. After a short reminder to 
make sure that the printer is ready, the entire document is printed. 
Printing can be aborted by pressing any key; there may be a short delay 
before this takes effect. If your printer has a large buffer, or you are 
using a print spooler, it will be some time before printing ceases. However 
you can immediately continue editing the document.

Printing a block
----------------

This function will print a marked block of text. Type <Alternate> B, or 
select 'Print block'. Any page breaks inside the block will be used 
normally, so you may need to consider if these are in appropriate positions 
in the block. If you need to set the page breaks at particular points, it 
is probably easiest to copy the block to an empty document slot and work 
with this. In this way, the pagination of the main document does not have 
to be changed.

WORKING WITH BLOCKS
-------------------

Blocks are marked sections of text which can be copied and moved around in 
various ways. Only one block can be marked at any one time. When a block is 
marked it is displayed in inverted form (i.e. white letters on a black 
background). There is no limit to the size of a block - it can be the 
entire document if you wish.

The commands for manipulating blocks are all to be found under the 'Block' 
drop-down menu. Some of these commands make use of a reserved area of 
memory called the Clipboard Area. This area contains ten independent 
clipboards, which can be copied anywhere in the text, saved to disk, or 
carried over to a different document. Marked blocks can be freely copied or 
moved between different documents in memory.

There are two different modes of operation for using the clipboards, called 
'Auto' and 'Manual' modes: if you copy a block of text to the clipboard in 
'Auto' mode, SCRIBE searches for the first unused clipboard, and copies the 
text to this; if all ten clipboards are in use, an error message is 
displayed. If on the other hand you are using 'Manual' mode, the text is 
copied to whichever clipboard is currently active, replacing any text which 
is already there. If warnings are enabled, a warning will be displayed 
before any clipboard text is overwritten.

The setting of 'Auto' or 'Manual' mode is described later, under 
'MISCELLANEOUS FUNCTIONS'.

A block can be marked in two ways, as follows. When a new block is marked, 
any previously marked block is unmarked:

(a) Position the cursor where you want the block to start, and type 
<Control> B or select 'Mark block start/end'. Now position the cursor where 
you want the block to end, and type <Control> B or select 'Mark block 
start/end' again. The block is now marked.

(b) Position the mouse pointer where you want the block to start, and press 
the left mouse button. While holding down the left button, drag the mouse 
pointer downwards to where you want the block to end, and release the 
button. The block is now marked. If the mouse pointer is dragged to the top 
or bottom of the window during this operation, the text will scroll in the 
appropriate direction. As the pointer is dragged, the area of text which 
has been selected is progressively displayed inverted.

The commands to manipulate blocks are as follows:-

Copy to clipboard (<Control> C) - the block is copied to one of the 
clipboards, depending on the mode ('Auto' or 'Manual'). If in 'Auto' mode, 
the new clipboard becomes the currently active one, and this is indicated 
in the information line at the top of the window. The block is not deleted 
from the main text.

Cut to clipboard (<Control> T) - the block is copied to one of the 
clipboards as above, and the block is deleted from the main text.

Add to clipboard (<Control> A) - the block is copied to the currently 
active clipboard, appending it to any text which is already there. The 
block is not deleted from the main text.

Paste from clipboard (<Control> P) - the total contents of the currently 
active clipboard are inserted into the main text at the cursor position; 
the succeeding text is moved up to make room for it.

Duplicate block (<Control> D) - the block is copied to the current cursor 
position without deleting the original. The block does not have to be in 
the same document as the cursor. This operation does not affect the 
contents of any of the clipboards.

Move block (<Control> M) - the block is copied to the current cursor 
position, then the original is deleted. The block does not have to be in 
the same document as the cursor. This operation does not affect the 
contents of any of the clipboards.

Erase block (<Control> R) - the block is deleted from the main text.

Unmark block (<Control> U) - the block marking is removed.

Select clipboard (<Control> L) - a dialog box is displayed, in which you 
can make any one of the ten clipboards current by clicking on the 
appropriate button. When a block of text is copied to a clipboard, the 
first 30 characters are also copied to this dialog box, alongside the 
corresponding button. If you wish, you can erase this text and type in your 
own description of the contents of the clipboard. When you save all 
clipboards, the text descriptions are also saved.
You can also select a different clipboard directly without using the dialog 
box, by typing <Control> with a function key (e.g. <Control> F5 makes 
clipboard number 5 the currently active one). This is indicated in the 
information line at the top of the window.

Empty clipboard (<Control> E) - the contents of the currently active 
clipboard are totally deleted.

Empty all clipboards (<Control> X) - The contents of all ten clipboards are 
totally deleted.

Save clipboard and Save all clipboards - the contents of the currently 
active clipboard or all clipboards can be saved to disk. The procedures are 
described in the next section 'DISK OPERATIONS'.

DISK OPERATIONS
---------------

All of the following disk operations are accessed from the 'File' drop-down 
menu.

Saving text to disk
-------------------

While you are creating and editing a document, the information is held in 
the computer's memory. Before exiting from SCRIBE you need to save it to 
disk, otherwise it will be lost for ever.

Text can be saved in the special SCRIBE format, or as an ASCII file. The 
SCRIBE format preserves page break markers, headers and footers, so you 
should use this format if you intend later on to load the text back into 
SCRIBE for printing. For all other purposes you should normally use ASCII.

(a) SCRIBE file
---------------

To save the text in this form, select 'Save Scribe file', or type 
<Alternate> S. A file selector will be displayed. Select a different 
directory if you so wish, and choose or type a file name, then click on 
'OK' or press Return. If your chosen file name does not have the extension 
.SCB, SCRIBE will automatically add this extension, or replace a different 
extension with this one. If a file already exists in this directory with 
the same name, this file will be renamed with a .DUP extension before the 
text is saved.

When you have selected your file name as above, the data is saved to disk, 
after which you are returned to the position you were in before saving the 
data. You can now exit from SCRIBE or continue to work with it.

(b) ASCII file
--------------

As an alternative to the above, you can also save a text file in ASCII 
format. This means that the text is saved without any extra control 
characters, just pure text. You might want to do this if you are creating a 
document which is intended for printing from the Desktop or reading 
on-screen, or if you want to import the text into a word processor.

To do this, select 'ASCII save' or type <Alternate> A. A dialog box is 
displayed, asking you to choose whether you want paragraph markers after 
every line.

If you click on 'Yes', the text will be formatted into lines of up to 77 
characters, each line being terminated with the type of paragraph ending 
used in the current document (i.e. either a Carriage Return and Line Feed 
combination or a Line Feed only).
Line Feed on its own is not normally very useful as a line terminator, so 
if your document is in this format you should probably add Carriage Returns 
to the document before saving it, as described under 'MISCELLANEOUS 
FUNCTIONS'. This subject is discussed more fully in the section 'TECHNICAL 
NOTES' at the end of this manual.
Use CR+LF after every line if the file is intended for printing from the 
Desktop or reading on-screen, or for any other purpose in which each line 
of text has to be preserved as a separate item.

If you click on 'No', the text will not be formatted, and paragraph markers 
will be retained only at the ends of paragraphs (i.e. where the paragraph 
end symbol can be seen on the display). Use this style if the file is 
intended for importation into a word processor or another SCRIBE document.

Having made this choice, a file selector is displayed, in which you choose 
a directory and file name in the usual way. The file name can have any 
extension you like, and if a file already exists in this directory with the 
same name, this file will be renamed with a .BAK extension before the text 
is saved.

After making your selection the text will be saved to disk.

Note: ASCII save does not save page break markers, headers or footers, so 
if you want to preserve these you should also save the text in SCRIBE 
format.

(c) Clipboard
-------------

The contents of the current clipboard can be saved to disk as an ASCII 
file. After selecting 'Save clipboard', or typing <Alternate> C, the 
procedure is the same as for ASCII save.

(d) Save all clipboards
-----------------------

The contents of all ten clipboards, together with their text descriptions, 
can be saved to disk in a special format used for this purpose. Type 
<Alternate> K, or select 'Save all clipboards'.

A file selector is displayed, in which you can enter a filename, which must 
have a .CLP extension. If you use a different extension, or no extension at 
all, SCRIBE will change it to .CLP. After clicking on OK, the text is saved 
to disk. If a file already exists with the same name, it will be 
overwritten.


Loading data from disk
----------------------

Both SCRIBE files and ASCII files can be loaded into SCRIBE for further 
processing. SCRIBE files are recognised automatically.

Select 'Load text' or type <Alternate> L. A file selector is displayed, in 
which you choose the file to be loaded in the usual way. If your chosen 
file is found to be in SCRIBE format it will be treated appropriately; all 
other files are treated as pure ASCII. In principle these can be files of 
any sort; in practice, anything other than a text file will be largely 
unintelligible.

When you have selected the file to be loaded, SCRIBE loads it into the 
first available empty document slot; if all ten of the available document 
slots are already occupied, the text cannot be loaded, and an error message 
will be displayed. You will have to clear one of the slots before another 
document can be loaded.

Merging data from disk
----------------------

With this procedure, a disk file can be inserted into the document on which 
you are working. It is inserted in the text at the cursor position, and the 
succeeding text is moved up to make room.

Select 'Merge text' or type <Alternate> M. A file selector is displayed, in 
which you choose the file to be merged in the usual way. Either SCRIBE or 
ASCII files can be merged; if the former, any included page break markers 
will not be removed, so you will probably need to delete them if you intend 
to paginate the document for printing.

If the merged file has a different paragraph end format to the main 
document, its format will be automatically converted to that of the main 
document. See 'TECHNICAL NOTES' at the end of this manual for more 
information.

Loading clipboards
------------------

If you have previously used 'Save all clipboards' (see above), you can 
recover the information with this command. Type <Alternate> O, or select 
'Load clipboards'.

A file selector is displayed, in which you can select the appropriate .CLP 
file. If an incorrect type of file is selected, an error message will be 
displayed.

After selecting the file, it is loaded into the computer memory and made 
available for normal clipboard operations. The descriptive text can be 
viewed in the 'Select clipboard' dialog box (see under 'Block 
Operations').

Formatting floppy disks
-----------------------

Type <Alternate> F, or select 'Format floppy disk'. A dialog box is 
displayed, in which you select drive A or B, and whether you want single or 
double sided formatting. Click on 'Format' to format the disk, or 'Cancel' 
to abort the process.

Formatting proceeds 'backwards', i.e. from track 79 down to track zero. If 
you realise quickly that you are formatting the wrong disk, you can press 
any key to stop the process, and there is a good chance that the data on 
the disk will not be destroyed.

SEARCH AND REPLACE
------------------

SCRIBE provides facilities for finding a specified text string, and 
optionally replacing it with another text string. There are many uses for 
these facilities, such as:-

- finding a particular item of text in the document
- correcting repeated spelling mistakes
- speeding up typing by using abbreviations for common words or phrases, 
then later replacing the abbreviations by the full text

Select 'Search/replace' from the 'Search' menu, or type <Control> H. How 
you proceed depends on whether you are just searching or searching and 
replacing.

(a) Searching
-------------

Type into the top line of the dialog box the text which you want to look 
for. This can be any word or phrase of up to 50 characters.

In the middle of the dialog box are three buttons labelled 'Find', 
'Replace?' and 'Replace all'. Click on 'Find' to highlight it.

Now decide if the search is to be case sensitive or not. 'Case sensitive' 
means that an exact match of capitals and lower case letters will be made; 
'Case insensitive' means that capitals and lower case letters are treated 
as the same (AbCdEf, abcdef and ABCDEF are all considered equal). Click on 
the appropriate button, which will then be highlighted.

Finally you must choose whether the search is to start from the beginning 
of the document or from the current cursor position. Click on the 
appropriate button, which will then be highlighted.

Click on 'OK' to start the search. SCRIBE will now search from the selected 
starting point for your chosen text, and if it exists will display the 
relevant portion.

Your chosen text may occur several times. Having found the first example as 
described above, you can select 'Find next' under the 'Search' drop-down 
menu, or type <Control> F, to find the next example. This can be done 
repeatedly until there are no more to be found.

'Find next' always starts its search at the current cursor position; you 
can reposition the cursor anywhere in the document before selecting it. If 
you select 'Find next' before entering a search phrase, nothing will 
happen.


(b) Searching and replacing
---------------------------

With the dialog box displayed as described above, type the word or phrase 
for which you want to search, then press the down-arrow key or click the 
mouse in the area labelled 'Replacement text'. Type the text which you want 
to replace the search text.

Decide whether the search is to be case sensitive or not, and click on the 
appropriate button. (Note that this choice applies only to the search text; 
the replacement text will be inserted exactly as you typed it.)

From the row of three buttons, select 'Replace?' or 'Replace all'. If you 
choose 'Replace?', every replacement will be queried before being actioned. 
The relevant part of the text will be displayed, with the search text 
highlighted, and a message at the bottom of the screen asks you if you want 
it to be replaced or not. Type 'Y' to replace the text, or 'N' to leave it 
unchanged (you do not have to press Return after the Y or N). Having made 
your choice, the next occurrence of the search text will be displayed, and 
so on until the end of the document is reached. You can press Esc at any 
time if you want to abort the process.

If you choose 'Replace all', every occurrence of the search text will be 
replaced automatically without further prompting. When it is finished, the 
start of the document is redisplayed.

Choose whether the search is to start from the start of the document or 
from the current cursor position, then click on 'OK' to start the search 
and replace operation. It proceeds as described in the above two 
paragraphs.

Searching and replacing control characters
------------------------------------------

The search and replace facility can be used for non-printing (control) 
characters as well as for normal text. Hold down the Alternate key while 
typing the desired ASCII code on the numeric keypad. Release the Alternate 
key and the character appears. This method works in the search/replace 
dialog box, as well as in the body text.
You should use this capability with care, particularly with the line feed, 
form feed and carriage return characters (ASCII 10, 12 and 13), because 
these have special uses in SCRIBE documents.


MISCELLANEOUS FUNCTIONS
-----------------------

The following functions are all available from the 'Utilities' drop-down 
menu:-

(a) User preferences
--------------------

Type <Alternate> U, or select 'User preferences'. A dialog box is 
displayed, offering the following choices:

- Undo changes: The normal default is 'Yes', in which state the Undo 
facility is enabled. However, if memory is short, an extra 10,000 bytes can 
be made available for text by choosing 'No'. If you do this, the Undo 
facility will not be available.
The current status is shown in the information line at the top of the 
window.

- Online help: The normal default is 'Yes', which enables the on-line help 
facility. If you choose 'No', an extra 10,000 bytes of memory is made 
available for text, but the on-line help facility is disabled. If after 
disabling the help facility you subsequently want to reenable it, the file 
SCRIBE.HLP has to be loaded again from disk. If you are using floppy disks, 
you should make sure that the program disk is in the same drive as it was 
in when the program was first run. If SCRIBE cannot find the file, an error 
message will be displayed, and on-line help will not be available.
The current status is shown in the information line at the top of the 
window.

- Warnings: The normal default is 'Yes'. In this state, whenever any 
substantially destructive command is issued, a warning is displayed before 
the command is activated, and you are given the option to cancel it. If you 
find these warnings tedious, they can be disabled by choosing 'No'.

- Paragraph mark: Normally, paragraph endings are displayed on screen using 
the paragraph end symbol (a left-pointing arrow). If you prefer not to have 
these symbols displayed, select 'No'.

- Cursor: The normal cursor is a solid block. However, you can choose 
either a solid block or a vertical line by clicking on the appropriate 
button.

- Clipboard: Click on 'Auto' or 'Manual' to select the desired clipboard 
mode (see under 'BLOCK OPERATIONS'). The default mode is 'Auto'.
The current status is shown in the information line at the top of the 
window.

- Release memory: In its default state, SCRIBE takes control of all the 
available memory in the computer. In most circumstances this is not a 
problem, but if you want to release some memory for other purposes you can 
enter a suitable value here. This subject is discussed more fully in the 
appendix, under 'TECHNICAL NOTES'.

When you have made your choices as above, you have three options:-

- 'Save & Use' implements your choices and also saves them in the 
SCRIBE.DEF file, so that they become the new defaults when you next run 
SCRIBE. This function also saves the printed page layout settings (see 
under DOCUMENT PRINTING).

- 'Use' implements your choices for the current session only.

- 'Cancel' restores the choices to their previous settings.


(b) Reset paragraphs
--------------------

You may want to edit a document which has previously been saved in ASCII 
format and with paragraph markers at the end of every line (for example, 
README files supplied with programs are usually in this format). Editing 
such a document is rather tedious, because every line is in effect a 
separate paragraph. It is much easier if you first delete the unwanted 
paragraph markers, leaving only those which are actually wanted, and SCRIBE 
can give you some help with this:-

Type <Alternate> R, or select 'Reset paragraphs'. SCRIBE searches through 
the document for each paragraph marker, and uses an intelligent algorithm 
to decide if the marker should be retained or deleted. You can follow its 
progress as the slider on the vertical scroll bar moves down the screen.

When it has finished, you may have to do a little manual tidying-up to 
complete the process.


(c) Add carriage returns
------------------------

There are some documents to be found which use line feed as a paragraph 
terminator, instead of the far more common carriage return plus line feed 
combination. If such a document is loaded into SCRIBE, this utility can 
convert it to the normal CR/LF format.
Type <Alternate> N, or select 'Add carriage returns'. The document is 
converted, and you can follow its progress as the slider on the vertical 
scroll bar moves down the screen.


(d) Remove carriage returns
---------------------------

This utility does the opposite of (c) above. Type <Alternate> E, or select 
'Remove carriage returns'. The document is converted, and you can follow 
its progress as the slider on the vertical scroll bar moves down the 
screen.


(e) Show ASCII value
--------------------

This small utility returns the ASCII value of the character under the 
cursor. Type <Alternate> V, or select 'Show ASCII value'. Press Return or 
click on the button to return to the document. If the cursor is on the 
paragraph end marker, the value returned is the value of the paragraph end 
character (13 or 10), NOT the value of the left-pointing arrow.


(f) List documents
------------------

This item provides a list of all the documents currently in memory, with 
their sizes in bytes. It also indicates how much free memory remains 
available. Type <Alternate> D, or select 'List documents'.
Click the left mouse button or press any key to return to the document.


(g) On-line help
----------------

Provided that this facility has not been disabled, a shortened version of 
this instruction manual is available by selecting this item, or pressing 
the Help key. The first screen of the help text gives instructions for 
using it.
Select 'On-line help' or press the Help key again to return to the 
document.

Note that the on-line help file is a normal ASCII text file, so you can 
load it into SCRIBE and modify it if you wish. You may like to do this if 
there is some function in SCRIBE for which you need more explanation than 
is given in the help text. The only proviso is that the file must not 
exceed 10,000 bytes in length, otherwise SCRIBE will refuse to accept it as 
an on-line help file.

APPENDICES
==========

1. ERROR MESSAGES AND WARNINGS
------------------------------

Two types of error message may be displayed, those generated by the 
operating system, and those produced by SCRIBE:-

Operating system messages
-------------------------

These should occur only in the course of disk reading or writing 
operations. Some common messages, in abbreviated form, are:

"The disk... is physically write-protected..." - this will be displayed if 
the write protect tab in the corner of a floppy disk is in the open 
position when you try to save a file or format the disk. Push the tab into 
the closed position and try again.

"Drive A (or B) is not responding..." - this can occur in several 
circumstances:

- The disk is corrupted
- The disk is not formatted
- There is no disk in the drive
- You are using a double sided disk in a single sided drive
- You are using a high density disk in a normal density drive
- The drive is faulty

If there is a formatted disk of the correct type in the drive, you may 
still experience this message as a result of slight maladjustment of the 
disk drive heads. In this circumstance it is often worth trying again; a 
second or third attempt will often be successful. If you experience this 
message frequently, your disk drive is probably in need of repair, or you 
are using very unreliable disks.

"Disk full" - Use a fresh disk.


SCRIBE error messages and warnings
----------------------------------

These can occur in a variety of circumstances, usually as a result of 
attempting an operation which is impossible or inappropriate in the current 
conditions. If warnings are enabled, warning messages will be displayed if 
you initiate a procedure which will erase substantial amounts of text. Most 
of these messages are quite self-explanatory, but those relating to memory 
limitation deserve some explanation. These messages are:-

"There is not enough free memory for this operation" - This can occur in 
several circumstances, when loading or merging a file, or during block 
operations.

Possible solutions are:-
- erase unwanted documents, after saving them if necessary
- empty unwanted clipboards
- save your documents, then re-boot the computer without desk accessories

If you have a minimum-memory (512K) machine, it will be worth conserving 
your memory by not loading too many documents simultaneously. It may also 
be worth switching the clipboard mode to 'Manual' and only using clipboard 
number 1, to avoid filling the clipboard area with text which is no longer 
wanted there.

"Less than 10,000 bytes of memory remaining" - This warns you that memory 
is beginning to become short. You should consider the memory saving options 
given above if you want to add much more text to your document(s).

"Less than 5,000 bytes of memory remaining..." - Memory is now becoming 
quite short. You must consider the memory saving options, or finish adding 
text to your document(s).

"Nearly out of memory!" - Memory is now getting critical. Do NOT add any 
significant quantity of text before freeing some memory elsewhere.

"*** Out of memory ***" - If, despite the earlier warnings, you arrive at 
this stage, all is not lost, but you MUST stop editing your documents. All 
the functions of SCRIBE will still work, but the message will be repeatedly 
displayed until you erase some material to free up some additional memory. 
You are recommended to save all documents in memory before doing anything 
else.

2. INSTALLING SCRIBE AS AN APPLICATION
--------------------------------------

SCRIBE can be installed as an application. When this is done, 
double-clicking on a suitable text file will automatically run SCRIBE, then 
load the text file into it, in a single operation. This has more usefulness 
in a hard disk system, but is also possible with floppies. Note that this 
is only an option; it is NOT an essential part of using SCRIBE.

To install SCRIBE as an application, first find the SCRIBE.PRG icon from 
the Desktop, then click once on it so that it is highlighted. Now select 
'Install Application' from the 'Options' menu. This displays a small dialog 
box, in which you will see that SCRIBE.PRG has been entered as the 
application name. You have to enter a document type into the space 
indicated; this is the extension of the type of text file which you want to 
enable - it could be SCB for an SCRIBE file, or (for example) DOC or TXT 
for ASCII files, depending on your preference.

Finally, under 'Application type', click on 'GEM', then click on 'OK' to 
complete the installation. You can now run SCRIBE by double-clicking on any 
file which has the extension which you installed. To make your installation 
permanent, select 'Save Desktop' from the 'Options' menu (on the Desktop, 
not in SCRIBE). For this function to work in subsequent sessions, 
SCRIBE.PRG must be in the same folder, and in the same disk drive, as when 
you installed it.

Alternative desktops such as Neodesk provide similar functions. The exact 
procedure will be described in the manual supplied with the program. Some 
of these alternative desktops allow more than one document type to be 
installed for the same application.


3. TECHNICAL NOTES
------------------

Paragraph endings
-----------------

In its default state, SCRIBE conforms to the normal convention of ending 
paragraphs with a carriage return and line feed combination. However there 
are some documents in circulation which do not conform to this convention, 
using line feed alone as the paragraph terminator.
When SCRIBE loads a document, it checks to see which type of paragraph 
ending is used, and adapts its characteristics accordingly. Therefore, you 
do not normally need to be aware of which type of document is in memory, as 
the change in function is automatic, and transparent to the user.
If you do want to know which type of document you have loaded, the second 
item in the information line at the top of the window ('PARA') indicates 
the format of the current document.
SCRIBE includes routines for converting between the two formats as 
described  under 'MISCELLANEOUS FUNCTIONS'.
If you merge a document which has a different paragraph end format to the 
document into which it is being merged, the merged document will be 
automatically converted to the format of the main document.

Memory management
-----------------

By default, SCRIBE takes control of all the available memory in the 
computer for its own use. In most circumstances this is perfectly 
acceptable, but there can be situations in which some free memory is 
required for other purposes, e.g.:-

- you may need to call a desk accessory which requires extra memory, for 
example to set up a ramdisk or a print spooler.
- you may be using a multi-tasking operating system, and need to leave some 
free memory in which to load other programs.

The 'Release memory' facility in the 'User preferences' dialog box enables 
you to free some of the memory for such purposes. The figure which is 
entered in the dialog box is the total amount of memory which is to be 
untouched by SCRIBE (i.e. free for other purposes). This amount can be 
changed at any time; error messages will be displayed if unreasonable 
values are entered. SCRIBE will refuse to release more memory if the result 
would be to reduce its own free workspace to less than 32 kilobytes.

If you release some memory, then use some of it for another purpose, you 
will not be able to reset the released memory to zero until it is freed up 
by the other application or desk accessory which used it. Some public 
domain desk accessories have defective memory management and may cause some 
problems with this facility; therefore it is generally safer to set up 
ramdisks, print spoolers, etc. before running SCRIBE.

Using SCRIBE in low resolution
------------------------------

In principle, SCRIBE will work in any screen resolution. However, in the 
low resolution modes (less than 640 pixels horizontally) full functioning 
will not be available - part of the drop-down menu will be missing, and 
some dialog boxes will overflow the screen, leading to some corruption of 
the display. It is not therefore recommended to use SCRIBE in low 
resolution, but it can nevertheless be used in these modes for simple 
editing of small text files.

Note concerning TOS V1.04
-------------------------

There is a bug in the operating system version 1.04 ('Rainbow TOS') and 
some subsequent versions, which may affect users of SCRIBE. The effect of 
this bug is that single mouse clicks are sometimes interpreted as two 
clicks. If, for example, you click in the grey area of the scroll bar to 
scroll the text, it may scroll twice.

SCRIBE contains code which should avoid any occurrence of this bug. However 
if it does occur, proceed as follows: There is a public domain desk 
accessory called SCROLFIX.ACC supplied with SCRIBE. Copy this file to the 
root directory of your boot disk (i.e. not inside any folder) and reboot 
the computer by pressing the reset button. The system should now respond 
normally to mouse clicks.

SCROLFIX.ACC is a desk accessory, and it will unfortunately occupy one of 
the available six desk accessory slots, so you should install it only if it 
proves necessary.

Speed-up utilities
------------------

SCRIBE uses 'legal' operating system calls, so it should be compatible with 
speed-up utilities such as QuickST and WARP 9. The author uses QuickST 3, 
and this gives a dramatic increase in the speed of text output, drawing 
dialog boxes, etc. If you want to obtain maximum speed with SCRIBE, these 
utilities can be recommended.

